﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Datenaufbewahrung                                                                   //
//  _________________________________  													//
//                                                                                      //
//  Copyright (c) 2010 Reimar Grasbon													//
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "Conf.h"
#include "TypeDefs.h"
#include "PushMessage.h"
#include "TextFeed.h"
#include "Application.h"
#include "AlarmControl.h"
#include "AlarmUnit.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Definitionen  ////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
#define STORING_AddressOf(name)      ((void*)(CFG_EEP_STORING_PARTITION + offsetof(Storing, name)))
#define STORING_Load(name, value)    STORING_LoadBlock(STORING_AddressOf(name), value, sizeof(((Storing*)0)->name))
#define STORING_Save(value, name)    STORING_SaveBlock(value, STORING_AddressOf(name), sizeof(((Storing*)0)->name))
#define STORING_Default(name, value) STORING_LoadPGMMem(&factoryDef.name, value, sizeof(((Storing*)0)->name))

//////////////////////////////////////////////////////////////////////////////////////////
//  Typen  ///////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
typedef struct	               // Wertespeicherstruktur
{   char                       STO_DeviceLabel[61];
	bool                       STO_HeartbeatOnSystemLed;
	LedBusActivity			   STO_LedBusActivity;
	ContactEventConfiguration  STO_ContactEventConfiguration[CFG_CONTACT_COUNT][2];	
	// Einstellungen der Alarmeinheit
	EventSignal				   STO_EventSignal[5];
	StateSignal				   STO_StateSignal[6];
	UInt08                     STO_ActivationAnnouncementDuration;
	UInt08                     STO_TriggerAnnouncementDuration;
	TextFeed                   STO_TriggerTextFeed;	
	// Einstellungen der Alarmsystem-Steuereinheit										   
	bool					   STO_AlarmSystemEnabled;
	AlarmSystemInitialState    STO_AlarmSystemInitialState;
	UInt08					   STO_AlarmControlTriggerDuration;
	PushMessage				   STO_AlarmControlEventPushMessage[5];
	TextFeed				   STO_AlarmControlEventTextFeed[4];
} Storing;

//////////////////////////////////////////////////////////////////////////////////////////
//  Konstanten  //////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
extern const Storing  factoryDef;

//////////////////////////////////////////////////////////////////////////////////////////
//  Funktionen  //////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void        STORING_LoadBlock(const void*, void*, UInt16);
void        STORING_SaveBlock(const void*, void*, UInt16);
void        STORING_RestoreDefaults(void);
Cy4Address  STORING_LoadCy4SelfAdr(void);
void        STORING_SaveCy4SelfAdr(Cy4Address);

//////////////////////////////////////////////////////////////////////////////////////////
//  Prozessaufrufe  //////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void        STORING_Startup(void);
void        STORING_Proceed(void);
void        STORING_Shutdown(void);

//////////////////////////////////////////////////////////////////////////////////////////

